@@ -118,6 +118,26 @@ def accuracy(labels1,labels2,subsample_size='none'):
     trans_labels = translate_labellings(labels1,labels2,subsample_size)
     return sum(trans_labels==numpyify(labels2))/len(labels1)
 
+def f1(bin_classifs_pred,bin_classifs_gt):
+    tp = sum(bin_classifs_pred*bin_classifs_gt)
+    if tp==0: return 0
+    fp = sum(bin_classifs_pred*~bin_classifs_gt)
+    fn = sum(~bin_classifs_pred*bin_classifs_gt)
+
+    prec = tp/(tp+fp)
+    rec = tp/(tp+fn)
+    return (2*prec*rec)/(prec+rec)
+
+def mean_f1(labels1,labels2):
+    subsample_size = min(len(labels1),30000)
+    trans_labels = translate_labellings(labels1,labels2,subsample_size)
+    lab_f1s = []
+    for lab in unique_labels(trans_labels):
+        lab_booleans1 = trans_labels==lab
+        lab_booleans2 = labels2==lab
+        lab_f1s.append(f1(lab_booleans1,lab_booleans2))
+    return sum(lab_f1s)/len(lab_f1s)
+
 def compress_labels(labels):
     if isinstance(labels,torch.Tensor): labels = labels.detach().cpu().numpy()
     x = sorted([lab for lab in set(labels) if lab != -1])
